@@ -228,8 +228,10 @@ colCheck <- function(a, b) {
 ## used for is.na(<nsparse>)  but not only:
 is.na_nsp <- function(x) {
     d <- x@Dim
-    new(if(d[1] == d[2]) "nsCMatrix" else "ngCMatrix",
-        Dim = d, Dimnames = x@Dimnames, p = rep.int(0L, d[2]+1L))
+    dn <- x@Dimnames
+    new(if(d[1] == d[2] && identical(dn[[1]], dn[[2]]))
+	"nsCMatrix" else "ngCMatrix",
+        Dim = d, Dimnames = dn, p = rep.int(0L, d[2]+1L))
 }
 
 ## Note: !isPacked(.)  i.e. `full' still contains
@@ -842,7 +844,7 @@ geClass <- function(x) {
 	      class(x))
 }
 
-.dense.prefixes <- c("d" = "di",
+.dense.prefixes <- c("d" = "tr", ## map diagonal to triangular
                      "t" = "tr",
                      "s" = "sy",
                      "g" = "ge")
